@@ -516,6 +516,60 @@ class TestBlueprint:
                     schema_ref
                 )
 
+    def test_blueprint_route_method_view_method_specify_methods(
+            self, app, schemas
+    ):
+        """Test calling route on MethodView specifying methods
+
+        Checks only registered methods appear in the doc
+        """
+        api = Api(app)
+        blp = Blueprint('test', __name__, url_prefix='/test')
+
+        @blp.route('/', methods=('GET', 'PUT', ))
+        class Resource(MethodView):
+
+            def get(self):
+                return "get"
+
+            def post(self):
+                return "post"
+
+            def put(self):
+                return "put"
+
+        api.register_blueprint(blp)
+        spec = api.spec.to_dict()
+
+        client = app.test_client()
+        assert client.get('test/').status_code == 200
+        assert client.post('test/').status_code == 405
+        assert client.put('test/').status_code == 200
+
+        assert tuple(spec["paths"]["/test/"].keys()) == ("get", "put")
+
+    def test_blueprint_route_tags(self, app):
+        """Check passing tags to route"""
+        blp = Blueprint('test', __name__, url_prefix='/test')
+
+        @blp.route('/test_1/', tags=["Tag 1", "Tag 2"])
+        def test_1():
+            pass
+
+        @blp.route('/test_2/')
+        def test_2():
+            pass
+
+        api = Api(app)
+        api.register_blueprint(blp)
+        spec = api.spec.to_dict()
+
+        assert (
+            spec["paths"]["/test/test_1/"]["get"]["tags"] ==
+            ["Tag 1", "Tag 2"]
+        )
+        assert spec["paths"]["/test/test_2/"]["get"]["tags"] == ["test", ]
+
     @pytest.mark.parametrize('openapi_version', ['2.0', '3.0.2'])
     def test_blueprint_response_schema(self, app, openapi_version, schemas):
         """Check response schema is correctly documented.
